@@ -60,7 +60,7 @@ static R_CallMethodDef CallEntries[] = {
     {"p4s_to_wkt", (DL_FUNC) &p4s_to_wkt, 2},
     {"wkt_to_p4s", (DL_FUNC) &wkt_to_p4s, 2},
     {"P6_SRID_show", (DL_FUNC) &P6_SRID_show, 6},
-//    {"P6_SRID_proj", (DL_FUNC) &P6_SRID_proj, 6},
+    {"P6_SRID_proj", (DL_FUNC) &P6_SRID_proj, 6},
     {"list_coordinate_ops", (DL_FUNC) &list_coordinate_ops, 5},
     {"ogrAutoIdentifyEPSG", (DL_FUNC) &ogrAutoIdentifyEPSG, 1},
     {"OGR_write", (DL_FUNC) &OGR_write, 1},
@@ -85,6 +85,9 @@ static R_CallMethodDef CallEntries[] = {
     {"proj_network_enabled", (DL_FUNC) &proj_network_enabled, 0},
     {"enable_proj_network", (DL_FUNC) &enable_proj_network, 0},
     {"disable_proj_network", (DL_FUNC) &disable_proj_network, 0},
+    {"get_source_crs", (DL_FUNC) &get_source_crs, 1},
+    {"proj_vis_order", (DL_FUNC) &proj_vis_order, 1},
+    {"OSR_is_projected", (DL_FUNC) &OSR_is_projected, 1},
     {"RGDAL_SetGeoTransform", (DL_FUNC) &RGDAL_SetGeoTransform, 2},
     {"RGDAL_GetNoDataValue", (DL_FUNC) &RGDAL_GetNoDataValue, 1},
     {"RGDAL_GetMetadata", (DL_FUNC) &RGDAL_GetMetadata, 2},
